==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/zh.js <==
'use strict';/*!
 * This is a `i18n` language object.
 *
 * Chinese (Traditional)
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *   Peter Dave Hello (Twitter: @PeterDaveHello)
 *
 * @see core/i18n.js
 */
(function (exports) {
	if (exports.zh === undefined) {
		exports.zh = {
			'mejs.plural-form': 0,			
			'mejs.download-file': '下載檔案',			
			'mejs.install-flash': '您正在使用未啟用或安裝Flash播放器的瀏覽器。請打開您的Flash Player插件,或從https://get.adobe.com/flashplayer/下載最新版本',			
			'mejs.fullscreen': '全螢幕',			
			'mejs.play': '播放',
			'mejs.pause': '暫停',			
			'mejs.time-slider': '時間軸',
			'mejs.time-help-text': '使用左/右箭頭快轉1秒,上/下箭頭快轉10秒。',
			'mejs.live-broadcast' : '現場直播',			
			'mejs.volume-help-text': '使用上/下箭頭提高或降低音量。',
			'mejs.unmute': '取消靜音',
			'mejs.mute': '靜音',
			'mejs.volume-slider': '音量控制鍵',			
			'mejs.video-player': '影片播放器',
			'mejs.audio-player': '音樂播放器',			
			'mejs.captions-subtitles': '字幕/標題',
			'mejs.captions-chapters': '章節',
			'mejs.none': '無',
			'mejs.afrikaans': '南非荷蘭語',
			'mejs.albanian': '阿爾巴尼亞人',
			'mejs.arabic': '阿拉伯語',
			'mejs.belarusian': '白俄羅斯',
			'mejs.bulgarian': '保加利亞語',
			'mejs.catalan': '加泰羅尼亞語',
			'mejs.chinese': '中文',
			'mejs.chinese-simplified': '简体中文',
			'mejs.chinese-traditional': '正體中文',
			'mejs.croatian': '克羅地亞語',
			'mejs.czech': '捷克',
			'mejs.danish': '丹麥語',
			'mejs.dutch': '荷蘭人',
			'mejs.english': '英語',
			'mejs.estonian': '愛沙尼亞語',
			'mejs.filipino': '菲律賓',
			'mejs.finnish': '芬蘭語',
			'mejs.french': '法語',
			'mejs.galician': '加利西亞',
			'mejs.german': '德語',
			'mejs.greek': '希臘語',
			'mejs.haitian-creole': '海地克里奧爾人',
			'mejs.hebrew': '希伯來語',
			'mejs.hindi': '印地語',
			'mejs.hungarian': '匈牙利',
			'mejs.icelandic': '冰島',
			'mejs.indonesian': '印尼語',
			'mejs.irish': '愛爾蘭',
			'mejs.italian': '意大利語',
			'mejs.japanese': '日本',
			'mejs.korean': '韓國人',
			'mejs.latvian': '拉脫維亞人',
			'mejs.lithuanian': '立陶宛語',
			'mejs.macedonian': '馬其頓',
			'mejs.malay': '馬來語',
			'mejs.maltese': '馬耳他',
			'mejs.norwegian': '挪威語',
			'mejs.persian': '波斯人',
			'mejs.polish': '波蘭語',
			'mejs.portuguese': '葡萄牙語',
			'mejs.romanian': '羅馬尼亞語',
			'mejs.russian': '俄羅斯',
			'mejs.serbian': '塞爾維亞人',
			'mejs.slovak': '斯洛伐克語',
			'mejs.slovenian': '斯洛文尼亞語',
			'mejs.spanish': '西班牙語',
			'mejs.swahili': '斯瓦希里語',
			'mejs.swedish': '瑞典語',
			'mejs.tagalog': '他加祿語',
			'mejs.thai': '泰國',
			'mejs.turkish': '土耳其語',
			'mejs.ukrainian': '烏克蘭',
			'mejs.vietnamese': '越南人',
			'mejs.welsh': '威爾士',
			'mejs.yiddish': '意第緒語'
		};
	}
})(mejs.i18n);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/medias/lib/mejs/lang/zh.js <==
/*!
 * This is a `i18n` language object.
 *
 * Chinese (Traditional)
 *
 * @author
 *   Jalios (Twitter: @Jalios)
 *   Sascha Greuel (Twitter: @SoftCreatR)
 *   Peter Dave Hello (Twitter: @PeterDaveHello)
 *
 * @see core/i18n.js
 */
(function (exports) {
    'use strict';	if (exports.zh === undefined) {
		exports.zh = {
			'mejs.plural-form': 0,			
			'mejs.download-file': '下載檔案',			
			'mejs.fullscreen': '全螢幕',			
			'mejs.play': '播放',
			'mejs.pause': '暫停',			
			'mejs.time-slider': '時間軸',
			'mejs.time-help-text': '使用左/右箭頭快轉1秒,上/下箭頭快轉10秒。',
			'mejs.live-broadcast' : '現場直播',			
			'mejs.volume-help-text': '使用上/下箭頭提高或降低音量。',
			'mejs.unmute': '取消靜音',
			'mejs.mute': '靜音',
			'mejs.volume-slider': '音量控制鍵',			
			'mejs.video-player': '影片播放器',
			'mejs.audio-player': '音樂播放器',			
			'mejs.captions-subtitles': '字幕/標題',
			'mejs.captions-chapters': '章節',
			'mejs.none': '無',
			'mejs.afrikaans': '南非荷蘭語',
			'mejs.albanian': '阿爾巴尼亞人',
			'mejs.arabic': '阿拉伯語',
			'mejs.belarusian': '白俄羅斯',
			'mejs.bulgarian': '保加利亞語',
			'mejs.catalan': '加泰羅尼亞語',
			'mejs.chinese': '中文',
			'mejs.chinese-simplified': '简体中文',
			'mejs.chinese-traditional': '正體中文',
			'mejs.croatian': '克羅地亞語',
			'mejs.czech': '捷克',
			'mejs.danish': '丹麥語',
			'mejs.dutch': '荷蘭人',
			'mejs.english': '英語',
			'mejs.estonian': '愛沙尼亞語',
			'mejs.filipino': '菲律賓',
			'mejs.finnish': '芬蘭語',
			'mejs.french': '法語',
			'mejs.galician': '加利西亞',
			'mejs.german': '德語',
			'mejs.greek': '希臘語',
			'mejs.haitian-creole': '海地克里奧爾人',
			'mejs.hebrew': '希伯來語',
			'mejs.hindi': '印地語',
			'mejs.hungarian': '匈牙利',
			'mejs.icelandic': '冰島',
			'mejs.indonesian': '印尼語',
			'mejs.irish': '愛爾蘭',
			'mejs.italian': '意大利語',
			'mejs.japanese': '日本',
			'mejs.korean': '韓國人',
			'mejs.latvian': '拉脫維亞人',
			'mejs.lithuanian': '立陶宛語',
			'mejs.macedonian': '馬其頓',
			'mejs.malay': '馬來語',
			'mejs.maltese': '馬耳他',
			'mejs.norwegian': '挪威語',
			'mejs.persian': '波斯人',
			'mejs.polish': '波蘭語',
			'mejs.portuguese': '葡萄牙語',
			'mejs.romanian': '羅馬尼亞語',
			'mejs.russian': '俄羅斯',
			'mejs.serbian': '塞爾維亞人',
			'mejs.slovak': '斯洛伐克語',
			'mejs.slovenian': '斯洛文尼亞語',
			'mejs.spanish': '西班牙語',
			'mejs.swahili': '斯瓦希里語',
			'mejs.swedish': '瑞典語',
			'mejs.tagalog': '他加祿語',
			'mejs.thai': '泰國',
			'mejs.turkish': '土耳其語',
			'mejs.ukrainian': '烏克蘭',
			'mejs.vietnamese': '越南人',
			'mejs.welsh': '威爾士',
			'mejs.yiddish': '意第緒語'
		};
	}
})(mejs.i18n);
